Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(212)

Unified Diff: third_party/WebKit/Source/bindings/scripts/code_generator_web_agent_api.py

Issue 2648173002: Rename webmodule codegen bits to WebAgentAPI. (Closed)
Patch Set: Changed to WebAgentAPI. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/bindings/scripts/code_generator_web_agent_api.py
diff --git a/third_party/WebKit/Source/bindings/scripts/code_generator_web_module.py b/third_party/WebKit/Source/bindings/scripts/code_generator_web_agent_api.py
similarity index 93%
rename from third_party/WebKit/Source/bindings/scripts/code_generator_web_module.py
rename to third_party/WebKit/Source/bindings/scripts/code_generator_web_agent_api.py
index 11c52e39ff264d7c8652e60a115d51a0524becad..89fa5e2ab6775daa0e37292c017a60aad66bb10c 100644
--- a/third_party/WebKit/Source/bindings/scripts/code_generator_web_module.py
+++ b/third_party/WebKit/Source/bindings/scripts/code_generator_web_agent_api.py
@@ -4,19 +4,19 @@
# pylint: disable=import-error,print-statement,relative-import
-"""Generates Blink Web Module bindings.
+"""Generates Web Agent API bindings.
-The Blink Web Module bindings provide a stable, IDL-generated interface for the
-Web Modules.
+The Web Agent API bindings provide a stable, IDL-generated interface for the
+Web Agents.
-The Web Modules are the high-level services like Autofill,
-Autocomplete, Translate, Distiller, Phishing Detector, and others. Web Modules
+The Web Agents are the high-level services like Autofill,
+Autocomplete, Translate, Distiller, Phishing Detector, and others. Web Agents
typically want to introspec the document and rendering infromation to implement
browser features.
The bindings are meant to be as simple and as ephemeral as possible, mostly just
wrapping existing DOM classes. Their primary goal is to avoid leaking the actual
-DOM classes to the Web Modules layer.
+DOM classes to the Web Agents layer.
"""
import os
@@ -30,7 +30,7 @@ from name_style_converter import NameStyleConverter
MODULE_PYNAME = os.path.splitext(os.path.basename(__file__))[0] + '.py'
STRING_INCLUDE_PATH = 'wtf/text/WTFString.h'
-WEB_MODULE_IDL_ATTRIBUTE = 'WebModuleAPI'
+WEB_AGENT_API_IDL_ATTRIBUTE = 'WebAgentAPI'
def interface_context(idl_interface, type_resolver):
@@ -143,7 +143,7 @@ class InterfaceContextBuilder(object):
return self.result
-class CodeGeneratorWebModule(CodeGeneratorBase):
+class CodeGeneratorWebAgentAPI(CodeGeneratorBase):
def __init__(self, info_provider, cache_dir, output_dir):
CodeGeneratorBase.__init__(self, MODULE_PYNAME, info_provider,
cache_dir, output_dir)
@@ -151,7 +151,7 @@ class CodeGeneratorWebModule(CodeGeneratorBase):
self.typedef_resolver = TypedefResolver(info_provider)
def get_template(self, file_extension):
- template_filename = 'web_module_interface.%s.tmpl' % file_extension
+ template_filename = 'web_agent_api_interface.%s.tmpl' % file_extension
return self.jinja_env.get_template(template_filename)
def generate_file(self, template_context, file_extension):
@@ -184,7 +184,7 @@ class CodeGeneratorWebModule(CodeGeneratorBase):
return None
interface = definitions.interfaces[definition_name]
- if WEB_MODULE_IDL_ATTRIBUTE not in interface.extended_attributes:
+ if WEB_AGENT_API_IDL_ATTRIBUTE not in interface.extended_attributes:
return None
return self.generate_interface_code(interface)

Powered by Google App Engine
This is Rietveld 408576698